@@ -7,7 +7,7 @@ import responses
 from django.test import TestCase, override_settings
 from requests.exceptions import RequestException
 
-from ..rws_client import ApiClient, NotAuthenticated, NotFound
+from ..rws_client import ApiClient, NotAuthenticated, NotFound, rws_language_code
 
 
 class TestApiClient(TestCase):
@@ -115,6 +115,8 @@ class TestApiClient(TestCase):
                 "fakedesc",
                 "faketemplate",
                 "fakelocation",
+                "en",
+                ["fr"],
             )
 
     @override_settings(
@@ -143,6 +145,8 @@ class TestApiClient(TestCase):
             "fakedesc",
             "faketemplate",
             "fakelocation",
+            "en",
+            ["fr", "de-de"],
         )
         self.assertEqual(len(responses.calls), 1)
         self.assertDictEqual(
@@ -152,6 +156,16 @@ class TestApiClient(TestCase):
                 "description": "fakedesc",
                 "projectTemplate": {"id": "faketemplate"},
                 "location": "fakelocation",
+                "languageDirections": [
+                    {
+                        "sourceLanguage": {"languageCode": "en"},
+                        "targetLanguage": {"languageCode": "fr"},
+                    },
+                    {
+                        "sourceLanguage": {"languageCode": "en"},
+                        "targetLanguage": {"languageCode": "de-de"},
+                    },
+                ],
             },
             json.loads(responses.calls[0].request.body),
         )
@@ -184,6 +198,8 @@ class TestApiClient(TestCase):
                 "fakedesc",
                 "faketemplate",
                 "fakelocation",
+                "en",
+                ["fr"],
             )
         self.assertEqual(len(responses.calls), 1)
 
@@ -449,3 +465,13 @@ class TestApiClient(TestCase):
         with self.assertRaises(RequestException):
             client.get_project_templates()
         self.assertEqual(len(responses.calls), 1)
+
+    @override_settings(
+        WAGTAILLOCALIZE_RWS_LANGUAGECLOUD={
+            "LANGUAGE_CODE_MAP": {"en": "en-US", "fr": "fr-FR"}
+        }
+    )
+    def test_rws_language_code(self):
+        self.assertEqual(rws_language_code("en"), "en-US")
+        self.assertEqual(rws_language_code("fr"), "fr-FR")
+        self.assertEqual(rws_language_code("de"), "de")
